==> haskell-pipes-http-1.0.5-60-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes-http
version: 1.0.5
id: pipes-http-1.0.5-IUcu8Pn4n4mhogqVY1JWC
key: pipes-http-1.0.5-IUcu8Pn4n4mhogqVY1JWC
license: BSD3
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library
category: Pipes, Web
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Pipes.HTTP
abi: 551b1fe6f6bb9a06e371eb5ed21e395a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pipes-http-1.0.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/pipes-http-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/pipes-http-1.0.5
hs-libraries: HSpipes-http-1.0.5-IUcu8Pn4n4mhogqVY1JWC
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    pipes-4.3.5-EP7uCdFYWHu39wHQ9REWtE
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             pipes-4.3.5-EP7uCdFYWHu39wHQ9REWtE=70b2e8e2a6d34cd3bbc1e1a654d75135
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J=bfd2559218a81acc5cfe715436ea1e49
haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html: /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.5-61-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes-http
version: 1.0.5
id: pipes-http-1.0.5-NRMp46j02b6S2ibmqzCnT
key: pipes-http-1.0.5-NRMp46j02b6S2ibmqzCnT
license: BSD3
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library
category: Pipes, Web
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Pipes.HTTP
abi: 4900fa55c557b6195667ca82e258f47d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pipes-http-1.0.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/pipes-http-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/pipes-http-1.0.5
hs-libraries: HSpipes-http-1.0.5-NRMp46j02b6S2ibmqzCnT
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    pipes-4.3.5-EP7uCdFYWHu39wHQ9REWtE
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    http-client-tls-0.3.5.1-LB4pkcb8qGEBWLeuaQ6vBK
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             pipes-4.3.5-EP7uCdFYWHu39wHQ9REWtE=70b2e8e2a6d34cd3bbc1e1a654d75135
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             http-client-tls-0.3.5.1-LB4pkcb8qGEBWLeuaQ6vBK=2c976076a1c68f1c8d224058bac08c04
haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html: /usr/share/doc/haskell-pipes-http/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
